# -*- encoding: utf-8 -*-

import os
import shutil
import pkg_resources
import djangorecipe
from djangorecipe.recipe import Recipe as OriginalDjangoRecipe

################################################################################
# SETTINGS
################################################################################

conf_file = '''# -*- encoding: utf-8 -*

DATABASE_ENGINE = 'mysql'    # 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
DATABASE_NAME = ''
DATABASE_USER = ''           # Not used with sqlite3.
DATABASE_PASSWORD = ''       # Not used with sqlite3.
DATABASE_HOST = ''           # Set to empty string for localhost. Not used with sqlite3.
DATABASE_PORT = ''           # Set to empty string for default. Not used with sqlite3.
'''

production_settings = '''
from %(project)s.settings import *
'''

development_settings = '''
from %(project)s.settings import *
DEBUG=True
TEMPLATE_DEBUG=DEBUG
'''

auf_urls_template = '''# -*- encoding: utf-8 -*
from django.conf.urls.defaults import patterns, include, handler500, url
from django.conf import settings
from django.contrib import admin
from auf.django.skin.urls import auf_media_patterns

admin.autodiscover()

handler500 # Pyflakes

urlpatterns = patterns(
    '',
    url(r'^admin_tools/', include('admin_tools.urls')),
    (r'^admin/', include(admin.site.urls)),
    (r'^accounts/login/$', 'django.contrib.auth.views.login'),
)

if settings.DEBUG:
    urlpatterns += patterns('',
        (r'^media/(?P<path>.*)$', 'django.views.static.serve',
         {'document_root': settings.MEDIA_ROOT}),
    )
    urlpatterns += auf_media_patterns
'''
djangorecipe.recipe.urls_template = auf_urls_template

auf_settings_template = '''# -*- encoding: utf-8 -*-

import os
import socket
from conf import *

# Rapports d'erreurs
EMAIL_SUBJECT_PREFIX = '[%(project_name)s - %%s] ' %% socket.gethostname()
ADMINS = (
    ('Équipe ARI-SI', 'developpeurs@ca.auf.org'),
)

MANAGERS = ADMINS

TIME_ZONE = 'Canada/Montreal'

LANGUAGE_CODE = 'fr-ca'

# Absolute path to the directory that holds media.
# Example: "/home/media/media.lawrence.com/"
MEDIA_ROOT = %(media_root)s

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash if there is a path component (optional in other cases).
# Examples: "http://media.lawrence.com", "http://example.com/media/"
MEDIA_URL = '/media/'

# URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
# trailing slash.
# Examples: "http://foo.com/media/", "/media/".
ADMIN_MEDIA_PREFIX = '/admin_media/'

# Don't share this with anybody.
SECRET_KEY = '%(secret)s'

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.middleware.doc.XViewMiddleware',
)

ROOT_URLCONF = '%(urlconf)s'


INSTALLED_APPS = (
    'auf.django.skin',
    'admin_tools',
    'admin_tools.theming',
    'admin_tools.menu',
    'admin_tools.dashboard',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.admin',
    'south',
)

TEMPLATE_CONTEXT_PROCESSORS = (
    'django.core.context_processors.auth',
    'django.core.context_processors.debug',
    'django.core.context_processors.i18n',
    'django.core.context_processors.media',
    'django.contrib.messages.context_processors.messages',
    'django.core.context_processors.request',
    'auf.django.skin.context_processors.auf',
)


TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.load_template_source',
    'django.template.loaders.app_directories.load_template_source',
)

TEMPLATE_DIRS = (
    os.path.join(os.path.dirname(__file__), "templates"),
)


'''
djangorecipe.recipe.settings_template = auf_settings_template

################################################################################
# DEVELOPPEMENT
################################################################################
auf_development_settings = '''# -*- encoding: utf-8 -*-

from %(project)s.settings import *
DEBUG=True
TEMPLATE_DEBUG=DEBUG

# Décommentez ces lignes pour activer la debugtoolbar
#INTERNAL_IPS = ('127.0.0.1',)
#INSTALLED_APPS += ('debug_toolbar',)
#MIDDLEWARE_CLASSES += ('debug_toolbar.middleware.DebugToolbarMiddleware',)

AUTH_PASSWORD_REQUIRED = False
'''
djangorecipe.recipe.development_settings = auf_development_settings


################################################################################
# PRODUCTION
################################################################################
auf_production_settings = ''' # -*- encoding: utf-8 -*-

# En production, rediriger la sortie terminal on disponible en WSGI
# vers la sortie fichier errorlog.
import sys
sys.stdout = sys.stderr

from %(project)s.settings import *
'''
djangorecipe.recipe.production_settings = auf_production_settings

class Recipe(OriginalDjangoRecipe):

    def __init__(self, buildout, name, options):
        options.setdefault('project_name',  os.path.basename(buildout['buildout']['directory']))
        return super(Recipe, self).__init__(buildout, name, options)

    def create_project(self, project_dir):
        super(Recipe, self).create_project(project_dir)

        # fichier de configuration de base de données
        self.create_file(os.path.join(project_dir, 'conf.py'), conf_file, self.options)

        os.mkdir(os.path.join(project_dir, 'media', 'css'))
        os.mkdir(os.path.join(project_dir, 'media', 'images'))
        os.mkdir(os.path.join(project_dir, 'media', 'js'))

        # copie des medias django-admin-tools
        requirements, ws = self.egg.working_set(['djangorecipe'])
        req = pkg_resources.Requirement.parse('django-admin-tools')
        src = os.path.join(ws.find(req).location, 'admin_tools', 'media', 'admin_tools')
        dst = os.path.join(project_dir, 'media', 'admin_tools')
        shutil.copytree(src, dst)
